#[repr(i32)]pub enum EcPointFormat {
UnknownFormat = 0,
Uncompressed = 1,
Compressed = 2,
DoNotUseCrunchyUncompressed = 3,
}Variants
UnknownFormat = 0
Uncompressed = 1
Compressed = 2
DoNotUseCrunchyUncompressed = 3
Like UNCOMPRESSED but without the \x04 prefix. Crunchy uses this format. DO NOT USE unless you are a Crunchy user moving to Tink.
Implementations
Sourceimpl EcPointFormat
impl EcPointFormat
Sourceimpl EcPointFormat
impl EcPointFormat
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.