pub struct AesCtrHmacAeadKeyFormat {
pub aes_ctr_key_format: Option<AesCtrKeyFormat>,
pub hmac_key_format: Option<HmacKeyFormat>,
}Fields
aes_ctr_key_format: Option<AesCtrKeyFormat>hmac_key_format: Option<HmacKeyFormat>Trait Implementations
Sourceimpl Clone for AesCtrHmacAeadKeyFormat
impl Clone for AesCtrHmacAeadKeyFormat
Sourcefn clone(&self) -> AesCtrHmacAeadKeyFormat
fn clone(&self) -> AesCtrHmacAeadKeyFormat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AesCtrHmacAeadKeyFormat
impl Debug for AesCtrHmacAeadKeyFormat
Sourceimpl Default for AesCtrHmacAeadKeyFormat
impl Default for AesCtrHmacAeadKeyFormat
Sourceimpl Message for AesCtrHmacAeadKeyFormat
impl Message for AesCtrHmacAeadKeyFormat
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AesCtrHmacAeadKeyFormat
impl PartialEq for AesCtrHmacAeadKeyFormat
impl Copy for AesCtrHmacAeadKeyFormat
impl StructuralPartialEq for AesCtrHmacAeadKeyFormat