pub struct JwtHmacKeyFormat {
pub version: u32,
pub algorithm: i32,
pub key_size: u32,
}Fields
version: u32algorithm: i32key_size: u32Implementations
Sourceimpl JwtHmacKeyFormat
impl JwtHmacKeyFormat
Sourcepub fn algorithm(&self) -> JwtHmacAlgorithm
pub fn algorithm(&self) -> JwtHmacAlgorithm
Returns the enum value of algorithm, or the default if the field is set to an invalid enum value.
Sourcepub fn set_algorithm(&mut self, value: JwtHmacAlgorithm)
pub fn set_algorithm(&mut self, value: JwtHmacAlgorithm)
Sets algorithm to the provided enum value.